macro_rules! empty {
[$T:ty] => { ... };
}Expand description
In situation requiring an array or slice with a generic type for
the items, passing the empty array or slice is a bit cumbersome,
e.g. &[] as &[&str]. This macro may or may not make this nicer.